<?php

class Ithemes_Sync_Verb_ITSEC_Modify_Malware_Schedule extends Ithemes_Sync_Verb {

	public static $name = 'itsec-modify-malware-schedule';
	public static $description = '';

	public $default_arguments = array(
		'action'   => null, //The action to be performed (add, edit or delete)
		'resource' => null, //The resource to check
		'options'  => null, //Resource options
	);

	public function run( $arguments ) {

		$settings = get_site_option( 'itsec_malware_scheduling' );

		//Make sure a valid action is present
		if ( ! isset( $arguments['action'] ) || ( $arguments['action'] !== 'add' && $arguments['action'] !== 'edit' && $arguments['action'] !== 'delete' ) ) {
			return array( 'error' => __( 'Invalid action. The argument "action" must be equal to "add," "edit" or "delete."', 'it-l10n-ithemes-security-pro' ) );
		}

		//Make sure a resource is present
		if ( ! isset( $arguments['resource'] ) || $arguments['resource'] === null ) {
			return array( 'error' => __( 'A valid resource must be included to process malware scheduling item"', 'it-l10n-ithemes-security-pro' ) );
		}

		switch ( $arguments['action'] ) {

			case 'add': //Add a scheduled item

				if ( $settings !== false && isset( $settings['individual'] ) && is_array( $settings['individual'] ) ) {

					$found = false; //assume they've requested an invalid resource

					foreach ( $settings['individual'] as $key => $item ) {

						if ( $item['resource'] == $arguments['resource'] ) {
							$found = $key;
						}

					}

					if ( $found !== false ) { //The resource they want to edit isn't scheduled

						return array( 'error' => __( 'Resource already present. Duplicate resource not added.', 'it-l10n-ithemes-security-pro' ) );

					} else {

						if ( ! isset( $arguments['options'] ) || ! is_array( $arguments['options'] ) || ! isset( $arguments['options']['type'] ) || ! ( absint( $arguments['options']['type'] ) <= 1 ) ) {
							return array( 'error' => __( 'Invalid options for adding resource. Please specify "type".', 'it-l10n-ithemes-security-pro' ) );
						}

						$type     = absint( $arguments['options']['type'] );
						$resource = trim( sanitize_text_field( $arguments['resource'] ) );

						if ( $type === 0 && ITSEC_Lib::validate_url( $resource ) === false ) {

							return array( 'error' => __( 'The resource provided does not appear to be a valid URL. Please try again.', 'it-l10n-ithemes-security-pro' ) );

						} elseif ( $type === 1 && file_exists( trailingslashit( ABSPATH ) . $resource ) === false ) {

							return array( 'error' => __( 'The resource provided does not appear to be a valid file. Please try again.', 'it-l10n-ithemes-security-pro' ) );

						}

						$item = array(
							'resource' => $resource,
							'type'     => $type,
						);

						$settings['individual'][] = $item;

					}

				} else {

					return array( 'error' => __( 'Invalid resource. The resource you are attempting to edit could not be found.', 'it-l10n-ithemes-security-pro' ) );

				}

				break;

			case 'edit': //Edit a scheduled item

				if ( $settings !== false && isset( $settings['individual'] ) && is_array( $settings['individual'] ) ) {

					$found = false; //assume they've requested an invalid resource

					foreach ( $settings['individual'] as $key => $item ) {

						if ( $item['resource'] == $arguments['resource'] ) {
							$found = $key;
						}

					}

					if ( $found === false ) { //The resource they want to edit isn't scheduled

						return array( 'error' => __( 'Invalid resource. The resource you are attempting to edit could not be found.', 'it-l10n-ithemes-security-pro' ) );

					} else {

						if ( ! isset( $arguments['options'] ) || ! is_array( $arguments['options'] ) ) {
							return array( 'error' => __( 'Invalid options for editing resource.', 'it-l10n-ithemes-security-pro' ) );
						}

					}

				} else {

					return array( 'error' => __( 'Invalid resource. The resource you are attempting to edit could not be found.', 'it-l10n-ithemes-security-pro' ) );

				}

				break;

			case 'delete': //Delete a scheduled item

				if ( $settings !== false && isset( $settings['individual'] ) && is_array( $settings['individual'] ) ) {

					foreach ( $settings['individual'] as $key => $item ) {

						if ( $item['resource'] == $arguments['resource'] ) {
							unset( $settings['individual'][$key] );
						}

					}

				} else {

					return true; //There was nothing to delete

				}

				break;

			default: //An invalid action that somehow wasn't caught before

				return array( 'error' => __( 'Invalid action. The argument "action" must be equal to "add," "edit" or "delete."', 'it-l10n-ithemes-security-pro' ) );
				break;

		}

		update_site_option( 'itsec_malware_scheduling', $settings );

		return true;

	}

}
