<?php

if ( ! class_exists( 'ITSEC_Malware_Scheduling_Setup' ) ) {

	class ITSEC_Malware_Scheduling_Setup {

		private
			$defaults;

		public function __construct() {

			global $itsec_setup_action;

			$this->defaults = array(
				'enabled'           => false,
				'standard'          => false,
				'standard_interval' => 1,
				'individual'        => array(
					array( 'type'     => 0,
					       'resource' => get_home_url(),
					       'interval' => 1,
					       'itype'    => 1,
					),
				),
			);

			if ( isset( $itsec_setup_action ) ) {

				switch ( $itsec_setup_action ) {

					case 'activate':
						$this->execute_activate();
						break;
					case 'upgrade':
						$this->execute_upgrade();
						break;
					case 'deactivate':
						$this->execute_deactivate();
						break;
					case 'uninstall':
						$this->execute_uninstall();
						break;

				}

			} else {
				wp_die( 'error' );
			}

		}

		/**
		 * Execute module activation.
		 *
		 * @since 4.0
		 *
		 * @return void
		 */
		public function execute_activate() {

			$options = get_site_option( 'itsec_malware_scheduling' );

			if ( $options === false ) {

				add_site_option( 'itsec_malware_scheduling', $this->defaults );

			}

		}

		/**
		 * Execute module deactivation
		 *
		 * @return void
		 */
		public function execute_deactivate() {

			delete_site_option( 'itsec_malware_scheduling_last_scans' );
		}

		/**
		 * Execute module uninstall
		 *
		 * @return void
		 */
		public function execute_uninstall() {

			$this->execute_deactivate();

			delete_site_option( 'itsec_malware_scheduling' );
			delete_site_option( 'itsec_malware_scheduling_report_queue' );

		}

		/**
		 * Execute module upgrade
		 *
		 * @return void
		 */
		public function execute_upgrade() {

			global $itsec_old_version;

			if ( $itsec_old_version < 4032 ) {

				$options = get_site_option( 'itsec_malware_scheduling' );

				if ( $options !== false && isset ( $options['standard_interval'] ) && absint( $options['standard_interval'] ) <= 60 ) {

					$options['standard_interval'] = 1;

				} elseif ( $options !== false && isset ( $options['standard_interval'] ) && absint( $options['standard_interval'] ) > 60 ) {

					$options['standard_interval'] = absint( $options['standard_interval'] / 60 );

				}

				update_site_option( 'itsec_malware_scheduling', $options );

			}

		}

	}

}

new ITSEC_Malware_Scheduling_Setup();